Revision: 201033
authorDremov Kirill (Nokia-D-MSW/Tampere) <kirill.dremov@nokia.com>
Thu, 02 Sep 2010 21:31:49 +0300
changeset 81 842c592edba7
parent 75 809df41c314e
child 85 ad9d655827ef
Revision: 201033 Kit: 201035
layers.sysdef.xml
usbclasses/usbbasicpersonality/src/10274797.rss
usbclasses/usbbasicpersonality/src/UsbActiveBasicHandlerImp.cpp
usbclasses/usbphoneasmodem/classimplementation/mscfileserver/inc/mscfileserversecuritypolicy.h
usbengines/usbotgwatcher/src/cusbotgwatcher.cpp
usbengines/usbwatcher/group/bld.inf
usbengines/usbwatcher/inc/usbvariation.rh
usbengines/usbwatcher/rom/mtp_symbian_temp.iby
usbservices_plat/usb_watcher_api/inc/usbpersonalityids.h
usbuis/group/bld.inf
usbuis/inc/msmmclient.h
usbuis/inc/msmmindicatorclient.h
--- a/layers.sysdef.xml	Wed Aug 18 10:48:20 2010 +0300
+++ b/layers.sysdef.xml	Thu Sep 02 21:31:49 2010 +0300
@@ -13,7 +13,6 @@
         <unit unitID="lcdo.usbservices.usbclasses.usbosdescriptorhandler" mrp="" bldFile="&layer_real_source_path;/usbclasses/usbosdescriptorhandler/group" filter="!sf_build" name="usbservices_usbclasses_usbosdescriptorhandler" />
         <unit unitID="lcdo.usbservices.usbclasses.msmmplugin" mrp="" bldFile="&layer_real_source_path;/usbclasses/msmmplugin/group" filter="!sf_build" name="usbservices_usbclasses_msmmplugin" />
         <unit unitID="lcdo.usbservices.usbclasses.usbhidclassdriver" mrp="" bldFile="&layer_real_source_path;/usbclasses/usbhidclassdriver/group" filter="!sf_build" name="usbservices_usbclasses_usbhidclassdriver" />
-        <unit unitID="lcdo.usbservices.usbuis.rndisui" mrp="" bldFile="&layer_real_source_path;/usbuis/rndisui/group" filter="!sf_build" name="usbservices_usbuis_rndisui" />
       </module>
       <module name="usbqtui">
         <unit unitID="lcdo.usbservices.usbuis.usbsettingsapp" mrp="" bldFile="&layer_real_source_path;/usbuis/usbsettingsapp" name="usbservices_usbuis_usbsettingsapp" proFile="USBSettingsApp.pro" qmakeArgs="-r" />
--- a/usbclasses/usbbasicpersonality/src/10274797.rss	Wed Aug 18 10:48:20 2010 +0300
+++ b/usbclasses/usbbasicpersonality/src/10274797.rss	Thu Sep 02 21:31:49 2010 +0300
@@ -76,15 +76,6 @@
 					default_data = "80000006"; //
 					opaque_data = " ";
 					}
-				,
-				IMPLEMENTATION_INFO
-					{
-					implementation_uid = 0xA000EA04;
-					version_no = 1;
-					display_name = "RNDIS";
-					default_data = "80000008";
-					opaque_data = " ";
-					}
 				};
 			}
 		};
--- a/usbclasses/usbbasicpersonality/src/UsbActiveBasicHandlerImp.cpp	Wed Aug 18 10:48:20 2010 +0300
+++ b/usbclasses/usbbasicpersonality/src/UsbActiveBasicHandlerImp.cpp	Thu Sep 02 21:31:49 2010 +0300
@@ -33,7 +33,6 @@
 	,IMPLEMENTATION_PROXY_ENTRY(0x10282C70, CUsbActiveBasicHandler::NewL)
     ,IMPLEMENTATION_PROXY_ENTRY(0x2000B5D2, CUsbActiveBasicHandler::NewL) // PCS+MTP
     ,IMPLEMENTATION_PROXY_ENTRY(0x20029E41, CUsbActiveBasicHandler::NewL) // PhoneAsModem
-    ,IMPLEMENTATION_PROXY_ENTRY(0xA000EA04, CUsbActiveBasicHandler::NewL) // RNDIS
     };
 
 /**
--- a/usbengines/usbotgwatcher/src/cusbotgwatcher.cpp	Wed Aug 18 10:48:20 2010 +0300
+++ b/usbengines/usbotgwatcher/src/cusbotgwatcher.cpp	Thu Sep 02 21:31:49 2010 +0300
@@ -37,8 +37,10 @@
 #include "errors.h"
 #include "debug.h"
 #include "panic.h"
+#ifndef STIF
 _LIT_SECURITY_POLICY_PASS( KAlwaysPassPolicy );
 _LIT_SECURITY_POLICY_C1( KLocalServicesPolicy, ECapabilityLocalServices );
+#endif
 
 // ---------------------------------------------------------------------------
 // 
--- a/usbengines/usbwatcher/group/bld.inf	Wed Aug 18 10:48:20 2010 +0300
+++ b/usbengines/usbwatcher/group/bld.inf	Thu Sep 02 21:31:49 2010 +0300
@@ -38,6 +38,5 @@
 ../conf/usbwatcher.confml MW_LAYER_CONFML(usbwatcher.confml)
 ../conf/usbwatcher_101F8801.crml MW_LAYER_CRML(usbwatcher_101F8801.crml)
 
-../rom/mtp_symbian_temp.iby CORE_MW_LAYER_IBY_EXPORT_PATH(mtp_symbian_temp.iby)
 // End of file
 
--- a/usbengines/usbwatcher/inc/usbvariation.rh	Wed Aug 18 10:48:20 2010 +0300
+++ b/usbengines/usbwatcher/inc/usbvariation.rh	Thu Sep 02 21:31:49 2010 +0300
@@ -29,7 +29,6 @@
 #define per_productId_MediaTransfer 0x4A4
 #define per_productId_PCSuiteMTP per_productId_PCSuite
 #define per_productId_ModemInstall      0x0396
-#define per_productId_RNDIS 0x03A3
 
 #define per_bcdDevice 0x0100
 
--- a/usbengines/usbwatcher/rom/mtp_symbian_temp.iby	Wed Aug 18 10:48:20 2010 +0300
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,199 +0,0 @@
-/*
-* Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
-* All rights reserved.
-* This component and the accompanying materials are made available
-* under the terms of "Eclipse Public License v1.0"
-* which accompanies this distribution, and is available
-* at the URL "http://www.eclipse.org/legal/epl-v10.html".
-*
-* Initial Contributors:
-* Nokia Corporation - initial contribution.
-*
-* Contributors:
-*
-* Description: Temporary include MTP components released by ex-Symbian
-*
-*/
-
-
-#ifndef MTPSYMBIANTEMP_IBY__
-#define MTPSYMBIANTEMP_IBY__
-
-// mtp_framework.iby
-#ifndef MTP_FRAMEWORK_IBY
-#define MTP_FRAMEWORK_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP Framework cenrep file (temporary until this can be described in ConfML)
-//data=ZPRIVATE\10202be9\10282fcc.cre					private\10202be9\10282fcc.cre
-// MTP Data Types Library
-file=ABI_DIR\BUILD_DIR\mtpdatatypes.dll    system\libs\mtpdatatypes.dll
-// MTP Framework Library
-file=ABI_DIR\BUILD_DIR\mtpframework.dll    			system\libs\mtpframework.dll
-// MTP SERVER
-file=ABI_DIR\BUILD_DIR\mtpserver.exe    system\libs\mtpserver.exe
-// MTP Client
-file=ABI_DIR\BUILD_DIR\mtpclient.dll    system\libs\mtpclient.dll
-// MTP Generic Transport API
-file=ABI_DIR\DEBUG_DIR\mtptransportapi.dll  system\libs\mtptransportapi.dll
-// MTP Data Provider API
-file=ABI_DIR\BUILD_DIR\mtpdataproviderapi.dll    system\libs\mtpdataproviderapi.dll
-// MTP Device Data Provider Extension API
-file=ABI_DIR\BUILD_DIR\mtpdevdpextnapi.dll    system\libs\mtpdevdpextnapi.dll
-// MTP Data Provider Utility
-file=ABI_DIR\BUILD_DIR\mtpdataproviderutility.dll    system\libs\mtpdataproviderutility.dll
-// MTP Proxy Data Provider
-ECOM_PLUGIN(mtpproxydp.dll, mtpproxydp.rsc)
-// MTP plugin registration resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\102827B1.rsc  resource\mtp\102827B1.rsc 
-// MTP dummydp resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\dummydp.rsc  resource\mtp\dummydp.rsc 
-// MTP Service Config resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\services.rsc  resource\mtp\services.rsc 
-// MTP Backup registration file
-data=EPOCROOT##epoc32\data\Z\private\102827a2\backup_registration.xml  private\102827a2\backup_registration.xml
-//MTP device icon property file 
-data=EPOCROOT##epoc32\data\Z\private\102827a2\mtpdevice.ico  private\102827a2\mtpdevice.ico
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_FRAMEWORK_IBY
-
-// mtp_filedp.iby
-#ifndef MTP_FILEDP_IBY
-#define MTP_FILEDP_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP Data Provider API
-ECOM_PLUGIN(mtpfiledp.dll, mtpfiledp.rsc)
-// MTP plugin registration resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\102827B0.rsc  resource\mtp\102827B0.rsc 
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_FILEDP_IBY
-
-// mtp_usbsic.iby
-#ifndef MTP_USBSIC_IBY
-#define MTP_USBSIC_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT) && defined(__USB)
-//MTP USB Data Types Library
-file=ABI_DIR\BUILD_DIR\mtpusbdatatypes.dll				system\libs\mtpusbdatatypes.dll
-//MTP USB Still Image Class Controller
-ECOM_PLUGIN(mtpusbsiccc.dll, mtpusbsiccc.rsc)
-//MTP USB SIC transport plugin
-ECOM_PLUGIN(mtpusbsicimp.dll, mtpusbsicimp.rsc)
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_USBSIC_IBY
-
-// mtppictbridgedp.iby
-#ifndef MTPPICTBRIDGEDP_IBY
-#define MTPPICTBRIDGEDP_IBY
-#ifdef __USB_PICTBRIDGE 
-// MTP data provider
-ECOM_PLUGIN(mtppictbridgedp.dll, mtppictbridgedp.rsc)
-data=EPOCROOT##epoc32\data\Z\resource\mtp\2001FE3C.rsc  resource\mtp\2001FE3C.rsc   
-#endif
-#endif //MTPPICTBRIDGEDP_IBY
-
-// rptp.iby
-#ifndef RPTP_IBY
-#define RPTP_IBY
-file=ABI_DIR\BUILD_DIR\rptp.dll        system\libs\rptp.dll
-#endif //RPTP_IBY
-
-// mtp_imagedp.iby
-#ifndef MTPIMAGEDP_IBY
-#define MTPIMAGEDP_IBY
-ECOM_PLUGIN(mtpimagedp.dll,mtpimagedp.rsc)
-data=EPOCROOT##epoc32\data\Z\resource\mtp\2001FCAE.rsc  resource\mtp\2001FCAE.rsc 
-#endif MTPIMAGEDP_IBY
-
-// mtp_statusservice.iby
-#ifndef MTP_STATUSSERVICE_IBY
-#define MTP_STATUSSERVICE_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP Data Provider API
-ECOM_PLUGIN(mtpstatusservice.dll, mtpstatusservice.rsc)
-// MTP plugin registration resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\2001a97f.rsc  resource\mtp\2001a97f.rsc 
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_STATUSSERVICE_IBY
-
-// mtp_metadataservice.iby
-#ifndef MTP_METADATAERVICE_IBY
-#define MTP_METADATASERVICE_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP Data Provider API
-ECOM_PLUGIN(mtpmetadataservice.dll, mtpmetadataservice.rsc)
-// MTP plugin registration resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\2001A9A3.rsc  resource\mtp\2001A9A3.rsc
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_METADATASERVICE_IBY
-
-// mtp_wmpextndp.iby
-#ifndef MTP_WMPEXTNDP_IBY
-#define MTP_WMPEXTNDP_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP Data Provider API
-ECOM_PLUGIN(mtpwmpextndp.dll, mtpwmpextndp.rsc)
-// MTP plugin registration resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\1028716c.rsc  resource\mtp\1028716c.rsc 
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_WMPEXTNDP_IBY
-
-// devicedp
-#ifndef MTP_DEVICEDP_IBY
-#define MTP_DEVICEDP_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP Device Data Provider
-ECOM_PLUGIN(mtpdevicedp.dll, mtpdevicedp.rsc)
-// MTP plugin registration resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\102827AF.rsc  resource\mtp\102827AF.rsc 
-#endif //__MTP_PROTOCOL_SUPPORT
-#endif  //MTP_DEVICEDP_IBY
-
-// pimproxy
-#ifndef MTP_PIMPROXY_IBY
-#define MTP_PIMPROXY_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP PIM proxy
-file=ABI_DIR\BUILD_DIR\mtppimproxy.dll    system\libs\mtppimproxy.dll
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_PIMPROXY_IBY
-
-// calendardp
-#ifndef MTP_CALENDARDP_IBY
-#define MTP_CALENDARDP_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP Data Provider API
-ECOM_PLUGIN(mtpcalendardp.dll, mtpcalendardp.rsc)
-// MTP plugin registration resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\102871B8.rsc  resource\mtp\102871B8.rsc 
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_CALENDARDP_IBY
-
-// taskdp
-#ifndef MTP_TASKDP_IBY
-#define MTP_TASKDP_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-// MTP Data Provider API
-ECOM_PLUGIN(mtptaskdp.dll, mtptaskdp.rsc)
-// MTP plugin registration resource file
-data=EPOCROOT##epoc32\data\Z\resource\mtp\10287013.rsc  resource\mtp\10287013.rsc 
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif // MTP_TASKDP_IBY
-
-// bluetooth
-#ifndef MTP_BT_IBY
-#define MTP_BT_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT) && defined(__USB)
-//MTP over Bluetooth Data Types Library
-file=ABI_DIR\BUILD_DIR\mtpbtdatatypes.dll               system\libs\mtpbtdatatypes.dll
-//MTP over Bluetooth transport plugin
-ECOM_PLUGIN(mtpbt.dll, mtpbt.rsc)
-#endif // __MTP_PROTOCOL_SUPPORT
-#endif// MTP_BT_IBY
-
-#ifndef MTP_CONTROLLER_IBY
-#define MTP_CONTROLLER_IBY
-#if defined(__MTP_PROTOCOL_SUPPORT)
-//MTP Controller LOCOD service plugin
-ECOM_PLUGIN(mtpcontroller.dll, mtpcontroller.rsc)
-#endif// __MTP_PROTOCOL_SUPPORT
-#endif// MTP_CONTROLLER_IBY
-#endif // MTPSYMBIANTEMP_IBY__
--- a/usbservices_plat/usb_watcher_api/inc/usbpersonalityids.h	Wed Aug 18 10:48:20 2010 +0300
+++ b/usbservices_plat/usb_watcher_api/inc/usbpersonalityids.h	Thu Sep 02 21:31:49 2010 +0300
@@ -25,7 +25,6 @@
 #define KUsbPersonalityIdMTP          0x04
 #define KUsbPersonalityIdPCSuiteMTP  0x05
 #define KUsbPersonalityIdModemInst  0x06
-#define KUsbPersonalityIdRNDIS       0x08
 
 #endif   // USBPERSONALITYIDS_H
 
--- a/usbuis/group/bld.inf	Wed Aug 18 10:48:20 2010 +0300
+++ b/usbuis/group/bld.inf	Thu Sep 02 21:31:49 2010 +0300
@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2006 Nokia Corporation and/or its subsidiary(-ies).
+* Copyright (c) 2006 - 2010 Nokia Corporation and/or its subsidiary(-ies).
 * All rights reserved.
 * This component and the accompanying materials are made available
 * under the terms of "Eclipse Public License v1.0"
@@ -17,7 +17,3 @@
 
 #include "../imageprintuiprovider/group/bld.inf"
 #include "../imageprintui/group/bld.inf"
-
-PRJ_EXPORTS
-../inc/msmmclient.h MW_LAYER_PLATFORM_EXPORT_PATH(usb/hostms/msmmclient.h)
-../inc/msmmindicatorclient.h MW_LAYER_PLATFORM_EXPORT_PATH(usb/hostms/msmmindicatorclient.h)
--- a/usbuis/inc/msmmclient.h	Wed Aug 18 10:48:20 2010 +0300
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,71 +0,0 @@
-/*
-* Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
-* All rights reserved.
-* This component and the accompanying materials are made available
-* under the terms of "Eclipse Public License v1.0"
-* which accompanies this distribution, and is available
-* at the URL "http://www.eclipse.org/legal/epl-v10.html".
-*
-* Initial Contributors:
-* Nokia Corporation - initial contribution.
-*
-* Contributors:
-*
-* Description:
-*
-*/
-
-/**
- @file
- @internalComponent
-*/
-
-#ifndef MSMMCLIENT_H
-#define MSMMCLIENT_H
-
-#include <e32std.h>
-#include "msmm_pub_def.h"
-
-/**
-RMsmmSession is the interface for MFDC to use the MSMM.
-*/
-NONSHARABLE_CLASS(RMsmmSession) : public RSessionBase
-{
-public: 
-    //  RMsmmSession Implementaion
-    IMPORT_C TInt Connect();
-    IMPORT_C TInt Disconnect();
-    IMPORT_C TVersion Version() const;
-    
-    /** Add USB Mass Storage Function to the MSMM synchronously.
-    @param aDevice Usb Mass Storage device description.
-    @param aInterfaceNumber The Usb Mass Storage interface number.
-    @param aInterfaceToken The Usb Mass Storage interface token.
-    @return Error code of IPC. 
-    */
-    IMPORT_C TInt AddFunction(const TUSBMSDeviceDescription& aDevice,
-            TUint8 aInterfaceNumber,
-            TUint32 aInterfaceToken);
-
-    /** Remove USB Mass Storage device from the MSMM synchronously.
-    @param aDevice Usb Mass Storage device description.
-    @return Error code of IPC.
-    */
-    IMPORT_C TInt RemoveDevice(TUint aDevice);
-
-    // Support for server-side out-of-memory testing. In release, these just
-    // return KErrNone.
-    IMPORT_C TInt __DbgFailNext(TInt aCount);
-    IMPORT_C TInt __DbgAlloc();
-    
-    
-private:
-    // RMsmmSession data member
-    TPckgBuf<TUSBMSDeviceDescription> iDevicePkg;
-    TUint8 iInterfaceNumber;
-    TUint32 iInterfaceToken;
-};
-
-#endif // MSMMCLIENT_H
-
-// End of file
--- a/usbuis/inc/msmmindicatorclient.h	Wed Aug 18 10:48:20 2010 +0300
+++ /dev/null	Thu Jan 01 00:00:00 1970 +0000
@@ -1,49 +0,0 @@
-/*
-* Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
-* All rights reserved.
-* This component and the accompanying materials are made available
-* under the terms of "Eclipse Public License v1.0"
-* which accompanies this distribution, and is available
-* at the URL "http://www.eclipse.org/legal/epl-v10.html".
-*
-* Initial Contributors:
-* Nokia Corporation - initial contribution.
-*
-* Contributors:
-*
-* Description:
-*
-*/
-
-/**
- @file
- @internalComponent
-*/
-
-#ifndef MSMMINDICATORCLIENT_H
-#define MSMMINDICATORCLIENT_H
-
-#include <e32std.h>
-
-/**
-RHostMassStorage is the interface for Mass Storage Indicator UI to use the MSMM.
-*/
-NONSHARABLE_CLASS(RHostMassStorage) : public RSessionBase
-{
-public: 
-    //  RHostMassStorage Implementation API to add a session to the running MSMM server
-    IMPORT_C TInt Connect();
-    IMPORT_C TInt Disconnect();
-    IMPORT_C TVersion Version() const;
-    
-    /** Dismount USB drives from File System asynchronously. The function will return immediately to the UI with complete status
-        The result of dismounting USB drives will be notified to the MSMM Plugin via CMsmmPolicyPluginBase
-        @return Error code of IPC.
-    */
-    IMPORT_C TInt EjectUsbDrives();    
-    
-};
-
-#endif // MSMMINDICATORCLIENT_H
-
-// End of file
--- a/usbclasses/usbphoneasmodem/classimplementation/mscfileserver/inc/mscfileserversecuritypolicy.h	Wed Aug 18 10:48:20 2010 +0300
+++ b/usbclasses/usbphoneasmodem/classimplementation/mscfileserver/inc/mscfileserversecuritypolicy.h	Thu Sep 02 21:31:49 2010 +0300
@@ -1,4 +1,4 @@
-// Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
@@ -21,24 +21,21 @@
 
 // USB masss storage Server Security Policy Definition
 
-const TUint KUsbMsServerRangeCount = 3;
+const TUint KUsbMsServerRangeCount = 2;
 
 const TInt KUsbMsServerRanges[KUsbMsServerRangeCount] = 
 	{
-	EMscFileStart,                // NetworkControl	[StartL/Stop]
-	EMscFileShutdown,				// DiskAdmin		[Shutdown]
+	EMscFileSetupLu,              // NetworkControl	[SetupLogicalUnitL/StartL/Stop/Shutdown]
     EMscFileShutdown + 1,         // fail (to KMaxInt)
 	};
 
 // Index numbers into KUsbMsServerElements[]
 const TInt KPolicyNetworkControl = 0;
-const TInt KPolicyDiskAdmin = 1;
 
 // Mapping IPCs to poicy element
 const TUint8 KUsbMsServerElementsIndex[KUsbMsServerRangeCount] = 
 	{
-	KPolicyNetworkControl,          // EMscFileStart & EMscFileStop 
-	KPolicyDiskAdmin,			 	// EMscFileShutdown 
+	KPolicyNetworkControl,          // EMscFileSetupLu, EMscFileStart, EMscFileStop, EMscFileShutdown
 	CPolicyServer::ENotSupported,   // EMscFileShutdown + 1 to KMaxTInt    
 	};
 
@@ -46,7 +43,6 @@
 const CPolicyServer::TPolicyElement KUsbMsServerElements[] = 
 	{
   		{ _INIT_SECURITY_POLICY_C1(ECapabilityNetworkControl), CPolicyServer::EFailClient },
-		{ _INIT_SECURITY_POLICY_C1(ECapabilityDiskAdmin), CPolicyServer::EFailClient},
 		// the EFailClient means that if the check fails 
         // the CheckFailed method with return KErrPermissionDenied
 	};